@@ -4,4 +4,4 @@ warnings.high('my.books.kobo is deprecated! Please use my.kobo instead!')
 
 from ..core.util import __NOT_HPI_MODULE__
 
-from ..kobo import *
+from ..kobo import *  # type: ignore[no-redef]
