@@ -123,8 +123,8 @@ from contextlib import contextmanager as ctx
 @ctx
 def _reset_config() -> Iterator[Config]:
     # todo maybe have this decorator for the whole of my.config?
-    from .cfg import override_config
-    with override_config(config) as cc:
+    from .cfg import _override_config
+    with _override_config(config) as cc:
         cc.enabled_modules  = None
         cc.disabled_modules = None
         cc.cache_dir        = None
